.. _ClassRef:

Class Reference
===============

.. currentmodule:: midiutil.MidiFile

.. autoclass:: MIDIFile
  :members: addNote, addTrackName, addTempo, addProgramChange, addControllerEvent, makeRPNCall, makeNRPNCall, changeTuningBank, changeTuningProgram,
    changeNoteTuning, addSysEx, addUniversalSysEx, writeFile, __init__ , addTimeSignature, addCopyright, addText, addKeySignature
